@@ -94,8 +94,9 @@ class Ktable(Data_table):
 
         if filename is not None:
             self.filename=filename
-        elif filename_filters:  # a none empty sequence returns a True in a conditional statement
-            self.filename=self._settings.list_files(*filename_filters,
+        elif filename_filters or (mol is not None and (xtable is None and path is None)): 
+        # a none empty sequence returns a True in a conditional statement
+            self.filename=self._settings.list_files(*filename_filters, molecule = mol,
                 only_one=True, search_path=search_path)[0]
 
         if self.filename is not None:
