@@ -52,8 +52,9 @@ class Ktable5d(Data_table):
 
         if filename is not None:
             self.filename=filename
-        elif filename_filters:  # a none empty sequence returns a True in a conditional statement
-            self.filename=self._settings.list_files(*filename_filters,
+        elif filename_filters or (mol is not None and path is None): 
+        # a none empty sequence returns a True in a conditional statement
+            self.filename=self._settings.list_files(*filename_filters, molecule = mol,
                 only_one=True, search_path=search_path)[0]
         if self.filename is not None:
             if self.filename.lower().endswith(('.hdf5', '.h5')):
@@ -676,6 +677,17 @@ class Ktable5d(Data_table):
         self.Nw=self.wns.size
         if remove_zeros : self.remove_zeros(deltalog_min_value=10.)
         self.setup_interpolation()
+    
+    def clip_spectral_range(self, wn_range=None, wl_range=None):
+        """Limits the data to the provided spectral range:
+
+           * Wavenumber in cm^-1 if using wn_range argument
+           * Wavelength in micron if using wl_range
+        """
+        super().clip_spectral_range(wn_range=wn_range, wl_range=wl_range)
+        if self.kdata is not None:
+            self.setup_interpolation()
+
 
 def read_Qdat(filename):
     """Reads Q.dat files LMDZ style and extract the vmr grid.
